@@ -22,14 +22,14 @@ def pyang_plugin_init():
     grammar.register_extension_module(md_module_name)
 
     # Register the special grammar
-    for stmt, occurance, (arg, rules), add_to_stmts in md_stmts:
+    for stmt, occurence, (arg, rules), add_to_stmts in md_stmts:
         grammar.add_stmt((md_module_name, stmt), (arg, rules))
         grammar.add_to_stmts_rules(add_to_stmts,
-                                   [((md_module_name, stmt), occurance)])
+                                   [((md_module_name, stmt), occurence)])
 
 md_stmts = [
 
-    # (<keyword>, <occurance when used>,
+    # (<keyword>, <occurence when used>,
     #  (<argument type name | None>, <substmts>),
     #  <list of keywords where <keyword> can occur>)
 
