@@ -1,6 +1,6 @@
 """Tree output plugin
 
-Compatible with RFC 8340.
+Compatible with RFC 8340 and RFC 8791.
 
 Idea copied from libsmi.
 """
@@ -63,6 +63,14 @@ class TreePlugin(plugin.PyangPlugin):
                                      help="Print ietf-restconf:yang-data " +
                                      "structures")
             )
+        if plugin.is_plugin_registered('structure'):
+            optlist.append(
+                optparse.make_option("--tree-print-structures",
+                                     dest="tree_print_structures",
+                                     action="store_true",
+                                     help="Print ietf-yang-structure-ext" +
+                                     ":structure")
+            )
         g = optparser.add_option_group("Tree output specific options")
         g.add_options(optlist)
 
@@ -141,6 +149,8 @@ def emit_tree(ctx, modules, fd, depth, llen, path):
     printed_header = []
 
     for module in modules:
+        if printed_header:
+            fd.write("\n")
         del printed_header[:]
 
         chs = [ch for ch in module.i_children
@@ -168,11 +178,11 @@ def emit_tree(ctx, modules, fd, depth, llen, path):
                 if (hasattr(augment, 'i_target_node') and
                     hasattr(augment.i_target_node, 'i_module') and
                     augment.i_target_node.i_module not in modules + mods):
+                    # this augment has not been printed; print it
+                    print_header(module)
                     if not section_delimiter_printed:
                         fd.write('\n')
                         section_delimiter_printed = True
-                    # this augment has not been printed; print it
-                    print_header(module)
                     print_path("  augment", ":", augment.arg, fd, llen)
                     mode = 'augment'
                     if augment.i_target_node.keyword == 'input':
@@ -248,6 +258,41 @@ def emit_tree(ctx, modules, fd, depth, llen, path):
                                    ctx.opts.tree_no_expand_uses,
                                    prefix_with_modname=ctx.opts.modname_prefix)
 
+        if ctx.opts.tree_print_structures:
+            sxs = module.search(('ietf-yang-structure-ext', 'structure'))
+            if len(sxs) > 0:
+                if not printed_header:
+                    print_header(module)
+                    printed_header = True
+                section_delimiter_printed = False
+                for sx in sxs:
+                    if not section_delimiter_printed:
+                        fd.write('\n')
+                        section_delimiter_printed = True
+                    fd.write("  structure %s:\n" % sx.arg)
+                    print_children(sx.i_children, module, fd, '  ', path,
+                                   'structure', depth, llen,
+                                   ctx.opts.tree_no_expand_uses,
+                                   prefix_with_modname=ctx.opts.modname_prefix)
+
+            sxs = module.search(('ietf-yang-structure-ext',
+                                 'augment-structure'))
+            if len(sxs) > 0:
+                if not printed_header:
+                    print_header(module)
+                    printed_header = True
+                section_delimiter_printed = False
+                for sx in sxs:
+                    if not section_delimiter_printed:
+                        fd.write('\n')
+                        section_delimiter_printed = True
+                    fd.write("  augment-structure %s:\n" % sx.arg)
+                    print_children(sx.i_children, module, fd, '  ', path,
+                                   'structure', depth, llen,
+                                   ctx.opts.tree_no_expand_uses,
+                                   prefix_with_modname=ctx.opts.modname_prefix)
+
+
 def unexpand_uses(i_children):
     res = []
     uses = []
